@@ -1,18 +1,18 @@
-/*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003-2019 Antonio Diaz Diaz.
+/* GNU Ocrad - Optical Character Recognition program
+   Copyright (C) 2003-2024 Antonio Diaz Diaz.
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 2 of the License, or
+   (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <algorithm>
@@ -26,7 +26,7 @@
 #include "bitmap.h"
 
 
-    // Creates a blank Bitmap
+// create a blank Bitmap
 Bitmap::Bitmap( const int l, const int t, const int r, const int b )
   : Rectangle( l, t, r, b ), data( height() )
   {
@@ -35,12 +35,12 @@ Bitmap::Bitmap( const int l, const int t, const int r, const int b )
   }
 
 
-    // Creates a Bitmap from part of another Bitmap
+// create a Bitmap from part of another Bitmap
 Bitmap::Bitmap( const Bitmap & source, const Rectangle & re )
   : Rectangle( re ), data( re.height() )
   {
   if( !source.includes( re ) )
-    Ocrad::internal_error( "bad parameter building a Bitmap from part of another one." );
+    throw Ocrad::Internal( "bad parameter building a Bitmap from part of another Bitmap." );
 
   const int ldiff = left()-source.left();
   const int tdiff = top()-source.top();
@@ -127,7 +127,7 @@ void Bitmap::add_rectangle( const Rectangle & re )
   }
 
 
-// Returns false if bitmap is empty
+// return false if bitmap is empty
 //
 bool Bitmap::adjust_height()
   {
@@ -148,7 +148,7 @@ bool Bitmap::adjust_height()
   }
 
 
-// Returns false if bitmap is empty
+// return false if bitmap is empty
 //
 bool Bitmap::adjust_width()
   {
@@ -169,7 +169,7 @@ bool Bitmap::adjust_width()
   }
 
 
-// Returns the total filled area of this Bitmap
+// return the total filled area of this Bitmap
 //
 int Bitmap::area() const
   {
@@ -183,7 +183,7 @@ int Bitmap::area() const
   }
 
 
-// Returns the central octagon filled area of this Bitmap
+// return the central octagon filled area of this Bitmap
 //
 int Bitmap::area_octagon() const
   {
@@ -208,7 +208,7 @@ int Bitmap::area_octagon() const
   }
 
 
-// Returns the size of the central octagon of this blob
+// return the size of the central octagon of this blob
 //
 int Bitmap::size_octagon() const
   {
@@ -385,9 +385,9 @@ int Bitmap::follow_bottom( int row, int col ) const
   }
 
 
-// Looks for an inverted-U-shaped curve near the top, then tests which of
-// the vertical bars goes deeper
-//
+/* Look for an inverted-U-shaped curve near the top, then test which of
+   the vertical bars goes deeper.
+*/
 bool Bitmap::top_hook( int *hdiff ) const
   {
   int row, lcol = 0, rcol = 0, black_section = 0, wmax = 0;
@@ -423,9 +423,9 @@ bool Bitmap::top_hook( int *hdiff ) const
   }
 
 
-// Looks for an U-shaped curve near the bottom, then tests which of
-// the vertical bars is taller
-//
+/* Look for an U-shaped curve near the bottom, then test which of
+   the vertical bars is taller.
+*/
 bool Bitmap::bottom_hook( int *hdiff ) const
   {
   int row, lcol = 0, rcol = 0, black_section = 0, wmax = 0;
