@@ -1,18 +1,18 @@
-/*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003-2019 Antonio Diaz Diaz.
+/* GNU Ocrad - Optical Character Recognition program
+   Copyright (C) 2003-2024 Antonio Diaz Diaz.
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 2 of the License, or
+   (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <algorithm>
@@ -32,9 +32,9 @@
 #include "feats.h"
 
 
-// Recognizes 2 blob characters.
-// ij!%:;=?|
-//
+/* Recognize 2 blob characters.
+   ij!%:;=?|
+*/
 void Character::recognize12( const Charset & charset, const Rectangle & charbox )
   {
   const Blob & b1 = blob( 0 );		// upper blob
@@ -79,7 +79,7 @@ void Character::recognize12( const Charset & charset, const Rectangle & charbox
       {
       if( b1.holes() && b2.holes() ) { add_guess( 'g', 0 ); return; }
       }
-    if( b1.hcenter() < b2.hcenter() )		// Looks for merged 'fi'
+    if( b1.hcenter() < b2.hcenter() )		// Look for merged 'fi'
       {
       if( b2.height() > b2.width() && b1.hcenter() < b2.left() &&
           b1.includes_hcenter( b2 ) && 4 * b1.height() > 5 * b2.height() &&
@@ -112,7 +112,7 @@ void Character::recognize12( const Charset & charset, const Rectangle & charbox
         }
       if( !b2.holes() && ( code == '.' || code == '\'' ) )
         {
-        // Looks for merged 'ri' or 'r'
+        // Look for merged 'ri' or 'r'
         if( f2.bp.minima( b2.height() / 4 ) == 2 &&
             b2.top() > b1.bottom() && b2.hcenter() < b1.left() )
           {
@@ -204,7 +204,8 @@ void Character::recognize12( const Charset & charset, const Rectangle & charbox
         else if( code == 'u' &&
                  5 * b1.width() <= b2.width() && 5 * b1.height() <= b2.width() )
           return;
-        else if( b1.bottom() < b2.vcenter() )
+        else if( b1.bottom() < b2.vcenter() /*&&
+                 b2.top() - b1.bottom() < 2 * b1.height()*/ )
           {
           int atype = '\'';
           if( UCS::isvowel( code ) && 2 * b1.width() > 3 * b1.height() &&
