@@ -1,18 +1,18 @@
-/*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003-2019 Antonio Diaz Diaz.
+/* GNU Ocrad - Optical Character Recognition program
+   Copyright (C) 2003-2024 Antonio Diaz Diaz.
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 2 of the License, or
+   (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <algorithm>
@@ -31,9 +31,9 @@
 #include "feats.h"
 
 
-// Tests if the lower half of character is open to the left, to the right,
-// and/or to the bottom
-//
+/* Test whether the lower half of character is open to the left, to the right,
+   and/or to the bottom.
+*/
 int Features::test_49ARegpq( const Rectangle & charbox ) const
   {
   const Bitmap & h = b.hole( 0 );
@@ -168,15 +168,15 @@ int Features::test_4ADQao( const Charset & charset, const Rectangle & charbox )
   }
 
 
-// Tests if the upper half of character is open to the left, to the right,
-// and/or to the bottom
-//
+/* Test whether the upper half of character is open to the left, to the right,
+   and/or to the bottom.
+*/
 int Features::test_6abd( const Charset & charset ) const
   {
   const Bitmap & h = b.hole( 0 );
 
-  if( 3 * h.width() < b.width() &&
-      ( bp.minima( b.height() / 4 ) != 1 || tp.minima( h.vcenter() - b.top() ) != 1 ) ) return 0;
+  if( 3 * h.width() < b.width() && ( bp.minima( b.height() / 4 ) != 1 ||
+        tp.minima( h.vcenter() - b.top() ) != 1 ) ) return 0;
 
   int col = h.hcenter();
   int row = b.seek_top( h.top(), col, false ) - 1;
