@@ -1,23 +1,24 @@
-/*  Ocradlib - Optical Character Recognition library
-    Copyright (C) 2009-2019 Antonio Diaz Diaz.
+/* Ocradlib - Optical Character Recognition library
+   Copyright (C) 2009-2024 Antonio Diaz Diaz.
 
-    This library is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
+   This library is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 2 of the License, or
+   (at your option) any later version.
 
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this library.  If not, see <http://www.gnu.org/licenses/>.
+   You should have received a copy of the GNU General Public License
+   along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <climits>
 #include <cstdio>
 #include <cstring>
+#include <new>
 #include <string>
 #include <vector>
 #include <stdint.h>
@@ -53,8 +54,8 @@ struct OCRAD_Descriptor
   };
 
 
-bool verify_descriptor( OCRAD_Descriptor * const ocrdes,
-                        const bool result = false )
+bool check_descriptor( OCRAD_Descriptor * const ocrdes,
+                       const bool result = false )
   {
   if( !ocrdes ) return false;
   if( !ocrdes->page_image || ( result && !ocrdes->textpage ) )
@@ -63,23 +64,23 @@ bool verify_descriptor( OCRAD_Descriptor * const ocrdes,
   }
 
 
+int OCRAD_api_version( void ) { return OCRAD_API_VERSION; }
+
 const char * OCRAD_version() { return OCRAD_version_string; }
 
 
 OCRAD_Descriptor * OCRAD_open()
   {
-  verbosity = -1;			// keep library silent
-  OCRAD_Descriptor * const ocrdes = new( std::nothrow ) OCRAD_Descriptor;
-  if( !ocrdes ) return 0;
-  return ocrdes;
+  verbosity = -1;				// keep library silent
+  return new( std::nothrow ) OCRAD_Descriptor;	// may be null
   }
 
 
 int OCRAD_close( OCRAD_Descriptor * const ocrdes )
   {
   if( !ocrdes ) return -1;
-  if( ocrdes->textpage ) delete ocrdes->textpage;
-  if( ocrdes->page_image ) delete ocrdes->page_image;
+  if( ocrdes->textpage ) { delete ocrdes->textpage; ocrdes->textpage = 0; }
+  if( ocrdes->page_image ) { delete ocrdes->page_image; ocrdes->page_image = 0; }
   delete ocrdes;
   return 0;
   }
@@ -102,8 +103,7 @@ int OCRAD_set_image( OCRAD_Descriptor * const ocrdes,
         image->mode != OCRAD_colormap ) )
     { ocrdes->ocr_errno = OCRAD_bad_argument; return -1; }
 
-  try
-    {
+  try {
     Page_image * const page_image = new Page_image( *image, invert );
     if( ocrdes->textpage )
       { delete ocrdes->textpage; ocrdes->textpage = 0; }
@@ -112,6 +112,8 @@ int OCRAD_set_image( OCRAD_Descriptor * const ocrdes,
     }
   catch( std::bad_alloc & )
     { ocrdes->ocr_errno = OCRAD_mem_error; return -1; }
+  catch( ... )
+    { ocrdes->ocr_errno = OCRAD_library_error; return -1; }
   return 0;
   }
 
@@ -128,8 +130,7 @@ int OCRAD_set_image_from_file( OCRAD_Descriptor * const ocrdes,
     }
   if( !infile ) { ocrdes->ocr_errno = OCRAD_bad_argument; return -1; }
   int retval = 0;
-  try
-    {
+  try {
     Page_image * const page_image = new Page_image( infile, invert );
     if( ocrdes->textpage )
       { delete ocrdes->textpage; ocrdes->textpage = 0; }
@@ -138,8 +139,10 @@ int OCRAD_set_image_from_file( OCRAD_Descriptor * const ocrdes,
     }
   catch( std::bad_alloc & )
     { ocrdes->ocr_errno = OCRAD_mem_error; retval = -1; }
-  catch( ... )
+  catch( Page_image::Error & )
     { ocrdes->ocr_errno = OCRAD_bad_argument; retval = -1; }
+  catch( ... )
+    { ocrdes->ocr_errno = OCRAD_library_error; retval = -1; }
   std::fclose( infile );
   return retval;
   }
@@ -147,7 +150,7 @@ int OCRAD_set_image_from_file( OCRAD_Descriptor * const ocrdes,
 
 int OCRAD_set_utf8_format( OCRAD_Descriptor * const ocrdes, const bool utf8 )
   {
-  if( !verify_descriptor( ocrdes ) ) return -1;
+  if( !check_descriptor( ocrdes ) ) return -1;
   ocrdes->control.utf8 = utf8;
   return 0;
   }
@@ -155,7 +158,7 @@ int OCRAD_set_utf8_format( OCRAD_Descriptor * const ocrdes, const bool utf8 )
 
 int OCRAD_set_threshold( OCRAD_Descriptor * const ocrdes, const int threshold )
   {
-  if( !verify_descriptor( ocrdes ) ) return -1;
+  if( !check_descriptor( ocrdes ) ) return -1;
   if( threshold < -1 || threshold > 255 )
     { ocrdes->ocr_errno = OCRAD_bad_argument; return -1; }
   ocrdes->page_image->threshold( threshold );
@@ -165,39 +168,46 @@ int OCRAD_set_threshold( OCRAD_Descriptor * const ocrdes, const int threshold )
 
 int OCRAD_scale( OCRAD_Descriptor * const ocrdes, const int value )
   {
-  if( !verify_descriptor( ocrdes ) ) return -1;
-  int retval = 0;
-  try { if( !ocrdes->page_image->change_scale( value ) ) retval = -1; }
-  catch( ... ) { retval = -1; }
-  if( retval < 0 ) ocrdes->ocr_errno = OCRAD_bad_argument;
-  return retval;
+  if( !check_descriptor( ocrdes ) ) return -1;
+  try { if( !ocrdes->page_image->change_scale( value ) )
+          { ocrdes->ocr_errno = OCRAD_bad_argument; return -1; } }
+  catch( std::bad_alloc & )
+    { ocrdes->ocr_errno = OCRAD_mem_error; return -1; }
+  catch( Page_image::Error & )
+    { ocrdes->ocr_errno = OCRAD_bad_argument; return -1; }
+  catch( ... )
+    { ocrdes->ocr_errno = OCRAD_library_error; return -1; }
+  return 0;
   }
 
 
 int OCRAD_recognize( OCRAD_Descriptor * const ocrdes, const bool layout )
   {
-  if( !verify_descriptor( ocrdes ) ) return -1;
-  Textpage * const textpage =
-    new( std::nothrow ) Textpage( *ocrdes->page_image, "",
-                                  ocrdes->control, layout );
-  if( !textpage )
+  if( !check_descriptor( ocrdes ) ) return -1;
+  try {
+    Textpage * const textpage =
+      new Textpage( *ocrdes->page_image, "", ocrdes->control, layout );
+    if( ocrdes->textpage ) delete ocrdes->textpage;
+    ocrdes->textpage = textpage;
+    }
+  catch( std::bad_alloc & )
     { ocrdes->ocr_errno = OCRAD_mem_error; return -1; }
-  if( ocrdes->textpage ) delete ocrdes->textpage;
-  ocrdes->textpage = textpage;
+  catch( ... )
+    { ocrdes->ocr_errno = OCRAD_library_error; return -1; }
   return 0;
   }
 
 
 int OCRAD_result_blocks( OCRAD_Descriptor * const ocrdes )
   {
-  if( !verify_descriptor( ocrdes, true ) ) return -1;
+  if( !check_descriptor( ocrdes, true ) ) return -1;
   return ocrdes->textpage->textblocks();
   }
 
 
 int OCRAD_result_lines( OCRAD_Descriptor * const ocrdes, const int blocknum )
   {
-  if( !verify_descriptor( ocrdes, true ) ) return -1;
+  if( !check_descriptor( ocrdes, true ) ) return -1;
   if( blocknum < 0 || blocknum >= ocrdes->textpage->textblocks() )
     { ocrdes->ocr_errno = OCRAD_bad_argument; return -1; }
   return ocrdes->textpage->textblock( blocknum ).textlines();
@@ -206,7 +216,7 @@ int OCRAD_result_lines( OCRAD_Descriptor * const ocrdes, const int blocknum )
 
 int OCRAD_result_chars_total( OCRAD_Descriptor * const ocrdes )
   {
-  if( !verify_descriptor( ocrdes, true ) ) return -1;
+  if( !check_descriptor( ocrdes, true ) ) return -1;
   int c = 0;
   for( int b = 0; b < ocrdes->textpage->textblocks(); ++b )
     for( int i = 0; i < ocrdes->textpage->textblock( b ).textlines(); ++i )
@@ -218,7 +228,7 @@ int OCRAD_result_chars_total( OCRAD_Descriptor * const ocrdes )
 int OCRAD_result_chars_block( OCRAD_Descriptor * const ocrdes,
                               const int blocknum )
   {
-  if( !verify_descriptor( ocrdes, true ) ) return -1;
+  if( !check_descriptor( ocrdes, true ) ) return -1;
   if( blocknum < 0 || blocknum >= ocrdes->textpage->textblocks() )
     { ocrdes->ocr_errno = OCRAD_bad_argument; return -1; }
   int c = 0;
@@ -231,7 +241,7 @@ int OCRAD_result_chars_block( OCRAD_Descriptor * const ocrdes,
 int OCRAD_result_chars_line( OCRAD_Descriptor * const ocrdes,
                              const int blocknum, const int linenum )
   {
-  if( !verify_descriptor( ocrdes, true ) ) return -1;
+  if( !check_descriptor( ocrdes, true ) ) return -1;
   if( blocknum < 0 || blocknum >= ocrdes->textpage->textblocks() ||
       linenum < 0 ||
       linenum >= ocrdes->textpage->textblock( blocknum ).textlines() )
@@ -244,7 +254,7 @@ int OCRAD_result_chars_line( OCRAD_Descriptor * const ocrdes,
 const char * OCRAD_result_line( OCRAD_Descriptor * const ocrdes,
                                 const int blocknum, const int linenum )
   {
-  if( !verify_descriptor( ocrdes, true ) ) return 0;
+  if( !check_descriptor( ocrdes, true ) ) return 0;
   if( blocknum < 0 || blocknum >= ocrdes->textpage->textblocks() ||
       linenum < 0 ||
       linenum >= ocrdes->textpage->textblock( blocknum ).textlines() )
@@ -265,7 +275,7 @@ const char * OCRAD_result_line( OCRAD_Descriptor * const ocrdes,
 
 int OCRAD_result_first_character( OCRAD_Descriptor * const ocrdes )
   {
-  if( !verify_descriptor( ocrdes, true ) ) return -1;
+  if( !check_descriptor( ocrdes, true ) ) return -1;
   int ch = 0;
   if( ocrdes->textpage->textblocks() > 0 &&
       ocrdes->textpage->textblock( 0 ).textlines() > 0 )
