@@ -1,18 +1,18 @@
-/*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003-2019 Antonio Diaz Diaz.
+/* GNU Ocrad - Optical Character Recognition program
+   Copyright (C) 2003-2024 Antonio Diaz Diaz.
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 2 of the License, or
+   (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <algorithm>
@@ -274,6 +274,7 @@ void enlarge_n( std::vector< std::vector< uint8_t > > & data, const int n )
     {
     const std::vector< uint8_t > & datarow = data[row];
     new_data.push_back( std::vector< uint8_t >() );
+    new_data.back().reserve( n * width );
     for( int col = 0; col < width; ++col )
       {
       const uint8_t d = datarow[col];
@@ -295,28 +296,28 @@ void mirror_left_right( std::vector< std::vector< uint8_t > > & data )
 
 void mirror_top_bottom( std::vector< std::vector< uint8_t > > & data )
   {
-  const int height = data.size();
-  for( int u = 0, d = height - 1; u < d; ++u, --d )
-    data[u].swap( data[d] );
+  std::reverse( data.begin(), data.end() );
   }
 
 
-void mirror_diagonal( std::vector< std::vector< uint8_t > > & data,
-                      Rectangle & re )
+void mirror_diagonal( std::vector< std::vector< uint8_t > > & data )
   {
-  const int size = std::max( re.height(), re.width() );
+  const int rows = data.size();
+  const int cols = ( data.empty() ? 0 : data[0].size() );
+  const int size = std::max( rows, cols );
+  if( rows <= 0 || cols <= 0 ) return;
 
-  if( re.height() < size )
+  if( rows < size )			// add rows
     {
     data.resize( size );
-    for( int row = re.height(); row < size; ++row )
+    for( int row = rows; row < size; ++row )
       data[row].resize( size );
     }
-  else if( re.width() < size )
-    for( int row = 0; row < re.height(); ++row )
+  else if( cols < size )		// add cols
+    for( int row = 0; row < rows; ++row )
       data[row].resize( size );
 
-  for( int row = 0; row < size; ++row )
+  for( int row = 1; row < size; ++row )
     {
     std::vector< uint8_t > & datarow = data[row];
     for( int col = 0; col < row; ++col )
@@ -326,26 +327,23 @@ void mirror_diagonal( std::vector< std::vector< uint8_t > > & data,
       }
     }
 
-  const int h = re.height(), w = re.width();
-  re.height( w ); re.width( h );
-  if( re.height() < size ) data.resize( re.height() );
-  else if( re.width() < size )
-    for( int row = 0; row < re.height(); ++row )
-      data[row].resize( re.width() );
+  // swap the number of rows and cols
+  if( cols < size ) data.resize( cols );
+  else if( rows < size )
+    for( int row = 0; row < cols; ++row )
+      data[row].resize( rows );
   }
 
 } // end namespace
 
 
-// Creates a Page_image from a OCRAD_Pixmap
+// create a Page_image from an OCRAD_Pixmap
 //
 Page_image::Page_image( const OCRAD_Pixmap & image, const bool invert )
-  : Rectangle( 0, 0, image.width - 1, image.height - 1 )
   {
-  data.resize( height() );
-  for( unsigned row = 0; row < data.size(); ++row )
-    data[row].reserve( width() );
-  const int rows = height(), cols = width();
+  const int rows = image.height, cols = image.width;
+  data.resize( rows );
+  for( int row = 0; row < rows; ++row ) data[row].reserve( cols );
 
   switch( image.mode )
     {
@@ -389,25 +387,25 @@ Page_image::Page_image( const OCRAD_Pixmap & image, const bool invert )
   }
 
 
-// Creates a reduced Page_image
+// create a reduced Page_image
 //
 Page_image::Page_image( const Page_image & source, const int scale )
-  : Rectangle( source ), maxval_( source.maxval_ ), threshold_( source.threshold_ )
+  : maxval_( source.maxval_ ), threshold_( source.threshold_ )
   {
   if( scale < 2 || scale > source.width() || scale > source.height() )
-    Ocrad::internal_error( "bad parameter building a reduced Page_image." );
+    throw Ocrad::Internal( "bad parameter building a reduced Page_image." );
 
   const int scale2 = scale * scale;
-  Rectangle::height( source.height() / scale );
-  Rectangle::width( source.width() / scale );
+  const int rows = source.height() / scale;
+  const int cols = source.width() / scale;
 
-  data.resize( height() );
-  for( int row = 0; row < height(); ++row )
+  data.resize( rows );
+  for( int row = 0; row < rows; ++row )
     {
     const int srow = ( row * scale ) + scale;
-    data[row].reserve( width() );
+    data[row].reserve( cols );
     std::vector< uint8_t > & datarow = data[row];
-    for( int col = 0; col < width(); ++col )
+    for( int col = 0; col < cols; ++col )
       {
       const int scol = ( col * scale ) + scale;
       int sum = 0;
@@ -428,25 +426,25 @@ void Page_image::threshold( const Rational & th )
   if( th >= 0 && th <= 1 )
     threshold_ = ( th * maxval_ ).trunc();
   else
-    threshold_ = otsu_th( data, *this, maxval_ );
+    threshold_ = otsu_th( data, Rectangle( height(), width() ), maxval_ );
   }
 
 
 void Page_image::threshold( const int th )
   {
   if( th >= 0 && th <= 255 ) threshold_ = ( th * maxval_ ) / 255;
-  else threshold_ = otsu_th( data, *this, maxval_ );
+  else threshold_ = otsu_th( data, Rectangle( height(), width() ), maxval_ );
   }
 
 
 bool Page_image::cut( const Rational ltwh[4] )
   {
-  Rectangle re = *this;
+  Rectangle re( height(), width() );
 
-  const int l = absolute_pos( ltwh[0], left(), right() );
+  const int l = absolute_pos( ltwh[0], 0, width() - 1 );
   if( l > re.left() ) { if( l < re.right() ) re.left( l ); else return false; }
 
-  const int t = absolute_pos( ltwh[1], top(), bottom() );
+  const int t = absolute_pos( ltwh[1], 0, height() - 1 );
   if( t > re.top() ) { if( t < re.bottom() ) re.top( t ); else return false; }
 
   const int r = l + absolute_pos( ltwh[2], 0, width() ) - 1;
@@ -458,24 +456,14 @@ bool Page_image::cut( const Rational ltwh[4] )
   if( re.width() < 3 || re.height() < 3 ) return false;
 
   // cutting is performed here
-  if( re.bottom() < bottom() ) data.resize( re.bottom() - top() + 1 );
-  if( re.right() < right() )
-    {
-    const int w = re.right() - left() + 1;
-    for( int row = data.size() - 1; row >= 0 ; --row ) data[row].resize( w );
-    }
-  if( re.top() > top() )
-    data.erase( data.begin(), data.begin() + ( re.top() - top() ) );
-  if( re.left() > left() )
-    {
-    const int d = re.left() - left();
-    for( int row = data.size() - 1; row >= 0 ; --row )
-      data[row].erase( data[row].begin(), data[row].begin() + d );
-    }
-  Rectangle::left( 0 );
-  Rectangle::top( 0 );
-  Rectangle::right( data[0].size() - 1 );
-  Rectangle::bottom( data.size() - 1 );
+  if( re.bottom() < height() - 1 ) data.resize( re.bottom() + 1 );
+  if( re.right() < width() - 1 )
+    for( int row = height() - 1; row >= 0 ; --row )
+      data[row].resize( re.right() + 1 );
+  if( re.top() > 0 ) data.erase( data.begin(), data.begin() + re.top() );
+  if( re.left() > 0 )
+    for( int row = height() - 1; row >= 0 ; --row )
+      data[row].erase( data[row].begin(), data[row].begin() + re.left() );
 
   return true;
   }
@@ -483,8 +471,8 @@ bool Page_image::cut( const Rational ltwh[4] )
 
 void Page_image::draw_mask( const Mask & m )
   {
-  const int t = std::max( top(), m.top() );
-  const int b = std::min( bottom(), m.bottom() );
+  const int t = std::max( 0, m.top() );
+  const int b = std::min( height() - 1, m.bottom() );
   if( t == m.top() && m.left( t ) >= 0 && m.right( t ) >= 0 )
     for( int col = m.left( t ); col <= m.right( t ); ++col )
       set_bit( t, col, true );
@@ -501,15 +489,15 @@ void Page_image::draw_mask( const Mask & m )
     if( rnew < 0 ) rnew = rprev;
     if( lprev >= 0 && lnew >= 0 )
       {
-      int c1 = std::max( left(), std::min( lprev, lnew ) );
-      int c2 = std::min( right(), std::max( lprev, lnew ) );
+      int c1 = std::min( lprev, lnew );
+      int c2 = std::min( width() - 1, std::max( lprev, lnew ) );
       for( int col = c1; col <= c2; ++col )
         set_bit( row, col, true );
       }
     if( rprev >= 0 && rnew >= 0 )
       {
-      int c1 = std::max( left(), std::min( rprev, rnew ) );
-      int c2 = std::min( right(), std::max( rprev, rnew ) );
+      int c1 = std::min( rprev, rnew );
+      int c2 = std::min( width() - 1, std::max( rprev, rnew ) );
       for( int col = c1; col <= c2; ++col )
         set_bit( row, col, true );
       }
@@ -520,10 +508,10 @@ void Page_image::draw_mask( const Mask & m )
 
 void Page_image::draw_rectangle( const Rectangle & re )
   {
-  const int l = std::max( left(), re.left() );
-  const int t = std::max( top(), re.top() );
-  const int r = std::min( right(), re.right() );
-  const int b = std::min( bottom(), re.bottom() );
+  const int l = std::max( 0, re.left() );
+  const int t = std::max( 0, re.top() );
+  const int r = std::min( width() - 1, re.right() );
+  const int b = std::min( height() - 1, re.bottom() );
   if( l == re.left() )
     for( int row = t; row <= b; ++row ) set_bit( row, l, true );
   if( t == re.top() )
@@ -537,48 +525,45 @@ void Page_image::draw_rectangle( const Rectangle & re )
 
 void Page_image::draw_track( const Track & tr )
   {
-  int l = std::max( left(), tr.left() );
-  int r = std::min( right(), tr.right() );
+  int l = std::max( 0, tr.left() );
+  int r = std::min( width() - 1, tr.right() );
   if( l == tr.left() )
     for( int row = tr.top( l ); row <= tr.bottom( l ); ++row )
-      if( row >= top() && row <= bottom() ) set_bit( row, l, true );
+      if( row >= 0 && row < width() ) set_bit( row, l, true );
   if( r == tr.right() )
     for( int row = tr.top( r ); row <= tr.bottom( r ); ++row )
-      if( row >= top() && row <= bottom() ) set_bit( row, r, true );
+      if( row >= 0 && row < height() ) set_bit( row, r, true );
   for( int col = l; col <= r; ++col )
     {
     int row = tr.top( col );
-    if( row >= top() && row <= bottom() ) set_bit( row, col, true );
+    if( row >= 0 && row < height() ) set_bit( row, col, true );
     row = tr.bottom( col );
-    if( row >= top() && row <= bottom() ) set_bit( row, col, true );
+    if( row >= 0 && row < height() ) set_bit( row, col, true );
     }
   }
 
 
-bool Page_image::change_scale( int n )
+bool Page_image::change_scale( int n )		// no change if n == 1
   {
-  if( n <= -2 )
-    { Page_image reduced( *this, -n ); *this = reduced; return true; }
-  if( n >= 2 )
+  if( n == 0 || n < -width() || n < -height() ) return false;
+  if( n <= -2 ) { Page_image reduced( *this, -n ); *this = reduced; }
+  else if( n >= 2 )
     {
     if( INT_MAX / n < width() * height() )
-      throw Error( "scale factor too big. 'int' will overflow." );
+      throw Error( "Scale factor too big; 'int' will overflow." );
     if( maxval_ == 1 )
       {
       if( n && ( n % 2 ) == 0 ) { enlarge_2b( data ); n /= 2; }
       else if( n && ( n % 3 ) == 0 ) { enlarge_3b( data ); n /= 3; }
       }
-    if( n >= 2 )
+    if( n >= 2 )	// scale 8-bit greyscale images keeping borders smooth
       {
       enlarge_n( data, n );
       if( maxval_ > 1 )
         { if( n <= 3 ) convol_23( data, n ); else convol_n( data, n ); }
       }
-    Rectangle::height( data.size() );
-    Rectangle::width( data[0].size() );
-    return true;
     }
-  return false;
+  return true;
   }
 
 
@@ -589,19 +574,19 @@ void Page_image::transform( const Transformation & t )
     case Transformation::none:
       break;
     case Transformation::rotate90:
-      mirror_diagonal( data, *this ); mirror_top_bottom( data ); break;
+      mirror_diagonal( data ); mirror_top_bottom( data ); break;
     case Transformation::rotate180:
       mirror_left_right( data ); mirror_top_bottom( data ); break;
     case Transformation::rotate270:
-      mirror_diagonal( data, *this ); mirror_left_right( data ); break;
+      mirror_diagonal( data ); mirror_left_right( data ); break;
     case Transformation::mirror_lr:
       mirror_left_right( data ); break;
     case Transformation::mirror_tb:
       mirror_top_bottom( data ); break;
     case Transformation::mirror_d1:
-      mirror_diagonal( data, *this ); break;
+      mirror_diagonal( data ); break;
     case Transformation::mirror_d2:
-      mirror_diagonal( data, *this );
+      mirror_diagonal( data );
       mirror_left_right( data ); mirror_top_bottom( data ); break;
     }
   }
