@@ -1,18 +1,18 @@
-/*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003-2014 Antonio Diaz Diaz.
+/* GNU Ocrad - Optical Character Recognition program
+   Copyright (C) 2003-2024 Antonio Diaz Diaz.
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 2 of the License, or
+   (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <algorithm>
@@ -26,6 +26,8 @@
 #include "rational.h"
 #include "rectangle.h"
 #include "track.h"
+#include "ucs.h"
+#include "user_filter.h"
 #include "bitmap.h"
 #include "blob.h"
 #include "character.h"
@@ -47,7 +49,7 @@ void delete_line( std::vector< Textline * > & textlinep_vector, int i )
   }
 
 
-// Build the vertical composite characters.
+// build the vertical composite characters
 //
 void join_characters( std::vector< Textline * > & tlpv )
   {
@@ -88,7 +90,61 @@ void join_characters( std::vector< Textline * > & tlpv )
 } // end namespace
 
 
-Textblock::Textblock( const Rectangle & page, const Rectangle & block,
+void Textblock::apply_filters( const Control & control )
+  {
+  if( textlines() <= 0 ) return;
+  for( unsigned f = 0; f < control.filters.size(); ++f )
+    {
+    if( control.filters[f].user_filterp )
+      {
+      for( int i = 0; i < textlines(); ++i )
+        tlpv[i]->apply_user_filter( *control.filters[f].user_filterp );
+      continue;
+      }
+    const Filter::Type filter = control.filters[f].type;
+    if( filter != Filter::text_block )
+      {
+      for( int i = 0; i < textlines(); ++i )
+        tlpv[i]->apply_filter( filter );
+      continue;
+      }
+    int l = right(), t = bottom(), r = left(), b = top();
+    for( int i = 0; i < textlines(); ++i )
+      {
+      const Textline & line = *tlpv[i];
+      int first = line.characters(), last = -1;
+      for( int j = line.big_initials(); j < line.characters(); ++j )
+        if( line.is_key_character( j ) )
+          { l = std::min( l, line.character(j).left() ); first = j; break; }
+      for( int j = line.characters() - 1; j >= first; --j )
+        if( line.is_key_character( j ) )
+          { r = std::max( r, line.character(j).right() ); last = j; break; }
+      if( i == 0 )
+        { for( int j = first; j <= last; ++j )
+            if( line.is_key_character( j ) )
+              t = std::min( t, line.character(j).top() ); }
+      else if( i == textlines() - 1 )
+        { for( int j = first; j <= last; ++j )
+            if( line.is_key_character( j ) )
+              b = std::max( b, line.character(j).bottom() ); }
+      }
+    if( r < l || b < t ) continue;		// can't apply filter; no text
+    Rectangle re( l, t, r, b );
+    for( int i = 0; i < textlines(); ++i )
+      {
+      Textline & line = *tlpv[i];
+      bool modified = false;
+      for( int j = line.characters() - 1; j >= 0; --j )
+        if( line.character(j).height() >= 2 * line.height() ||
+            !re.includes( line.character(j).vcenter(), line.character(j).hcenter() ) )
+          { line.delete_character( j ); modified = true; }
+      if( modified ) line.remove_leadind_trailing_duplicate_spaces();
+      }
+    }
+  }
+
+
+Textblock::Textblock( const int page_height, const Rectangle & block,
                       std::vector< Blob * > & blobp_vector )
   : Rectangle( block )
   {
@@ -228,7 +284,7 @@ Textblock::Textblock( const Rectangle & page, const Rectangle & block,
     else delete &b;
     }
 
-//  for( int i = 0; i < textlines(); ++i ) tlpv[i]->verify_big_initials();
+//  for( int i = 0; i < textlines(); ++i ) tlpv[i]->check_big_initials();
 
   // Insert short blobs.
   // Seek up, then seek down, needed for slanted or curved lines.
@@ -265,14 +321,14 @@ Textblock::Textblock( const Rectangle & page, const Rectangle & block,
     {
     const Textline * lp = tlpv[textlines()-1];
     for( int i = 0, c = 0; i < lp->characters(); ++i )
-      if( lp->character( i ).bottom() >= page.bottom() &&
+      if( lp->character( i ).bottom() >= page_height - 1 &&
           2 * ++c >= lp->characters() )
         { delete_line( tlpv, textlines() - 1 ); break; }
 
     lp = tlpv[0];
-    const int t = std::max( page.top(), 1 );
+    // page top == 0
     for( int i = 0, c = 0; i < lp->characters(); ++i )
-      if( lp->character( i ).top() <= t && 2 * ++c >= lp->characters() )
+      if( lp->character( i ).top() <= 1 && 2 * ++c >= lp->characters() )
         { delete_line( tlpv, 0 ); break; }
     }
   }
@@ -307,7 +363,7 @@ Textblock::Textblock( const Rectangle & page, const Rectangle & block,
 
   join_characters( tlpv );
 
-  for( int i = 0; i < textlines(); ++i ) tlpv[i]->verify_big_initials();
+  for( int i = 0; i < textlines(); ++i ) tlpv[i]->check_big_initials();
 
   // Fourth pass. Remove noise lines.
   if( textlines() >= 3 )
@@ -371,9 +427,7 @@ void Textblock::recognize( const Control & control )
     tlpv[i]->recognize2( control.charset );
     }
 
-  for( unsigned j = 0; j < control.filters.size(); ++j )
-    for( int i = 0; i < textlines(); ++i )
-      tlpv[i]->apply_filter( control.filters[j] );
+  apply_filters( control );
 
   // Remove unrecognized lines.
   for( int i = textlines() - 1; i >= 0; --i )
@@ -418,7 +472,7 @@ void Textblock::recognize( const Control & control )
 const Textline & Textblock::textline( const int i ) const
   {
   if( i < 0 || i >= textlines() )
-    Ocrad::internal_error( "line, index out of bounds." );
+    throw Ocrad::Internal( "textline: index out of bounds." );
   return *tlpv[i];
   }
 
@@ -436,7 +490,7 @@ void Textblock::print( const Control & control ) const
   {
   for( int i = 0; i < textlines(); ++i )
     tlpv[i]->print( control );
-  std::fputs( "\n", control.outfile );
+  std::fputc( '\n', control.outfile );
   }
 
 
@@ -450,7 +504,7 @@ void Textblock::dprint( const Control & control, bool graph, bool recursive ) co
                   tlpv[i]->characters(), i + 1 );
     tlpv[i]->dprint( control, graph, recursive );
     }
-  std::fputs( "\n", control.outfile );
+  std::fputc( '\n', control.outfile );
   }
 
 
