@@ -1,18 +1,18 @@
-/*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003-2019 Antonio Diaz Diaz.
+/* GNU Ocrad - Optical Character Recognition program
+   Copyright (C) 2003-2024 Antonio Diaz Diaz.
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 2 of the License, or
+   (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 class Page_image;
@@ -31,7 +31,7 @@ public:
   Textline & operator=( const Textline & tl );
   ~Textline();
   void set_track();
-  void verify_big_initials();
+  void check_big_initials();
 
   int big_initials() const { return big_initials_; }
   Character & character( const int i ) const;
