@@ -1,19 +1,18 @@
-/*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
-    2012, 2013 Antonio Diaz Diaz.
+/* GNU Ocrad - Optical Character Recognition program
+   Copyright (C) 2003-2024 Antonio Diaz Diaz.
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 2 of the License, or
+   (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <algorithm>
@@ -32,7 +31,7 @@
 #include "character.h"
 #include "textline.h"
 
-// All the code in this file is provisional and will be rewritten someday
+// All the code in this file is provisional and will be rewritten someday.
 
 
 namespace {
@@ -46,7 +45,7 @@ int find_space_or_hyphen( const std::vector< Character * > & cpv, unsigned i )
 } // end namespace
 
 
-     // transform some small letters to capitals
+// transform some small letters to capitals
 void Textline::check_lower_ambiguous()
   {
   int begin = big_initials();
@@ -240,8 +239,9 @@ void Textline::recognize2( const Charset & charset )
         }
       c1.recognize1( charset, charbox( c1 ) );
       c2.recognize1( charset, charbox( c2 ) );
-      if( ( c1.guesses() && c2.guesses() ) ||
-          ( ( c1.guesses() || c2.guesses() ) && c.width() > c.height() ) )
+      const bool good_c2 = ( c2.guesses() && c2.guess( 0 ).code != '\'' );
+      if( ( c1.guesses() && good_c2 ) ||
+          ( ( c1.guesses() || good_c2 ) && c.width() > c.height() ) )
         {
         c = c1; shift_characterp( new Character( c2 ) );
         if( !c1.guesses() ) --i; else if( c2.guesses() ) ++i;
@@ -381,6 +381,7 @@ void Textline::recognize2( const Charset & charset )
     }
 
   // transform small o or u with accent or diaeresis to capital
+  // transform small s or z with caron to capital
   {
   int begin = big_initials();
   bool isolated = false;	// isolated letters compare with all line
@@ -399,7 +400,8 @@ void Textline::recognize2( const Charset & charset )
       int code = c1.guess( 0 ).code;
       if( code < 128 || c1.blobs() < 2 ) continue;
       int codeb = UCS::base_letter( code );
-      if( codeb != 'o' && codeb != 'u' ) continue;
+      if( codeb != 'o' && codeb != 'u' && codeb != 's' && codeb != 'z' )
+        continue;
       const Blob & b1 = c1.blob( c1.blobs() - 1 );	// lower blob
       for( int j = begin; j < characters(); ++j ) if( j != i )
         {
@@ -470,7 +472,7 @@ void Textline::recognize2( const Charset & charset )
             case 'g': case 'j': case 'p': case 'q': case 'y':
                       cap = ( c1.bottom() + noise <= c2.bottom() ); break;
             case 'Q': cap = ( std::abs( c1.top() - c2.top() ) <= noise ); break;
-            default : cap = ( std::abs( c1.bottom() - c2.bottom() ) <= noise );
+            default: cap = ( std::abs( c1.bottom() - c2.bottom() ) <= noise );
             }
           }
         }
@@ -493,10 +495,10 @@ void Textline::recognize2( const Charset & charset )
         {
         switch( code )
           {
-          case 'g': case 'j': case 'p': case 'q': case 'y':
-                    if( c1.bottom() < c2.bottom() - 2 ) continue; break;
+          case 'g': case 'j': case 'p': case 'q':
+          case 'y': if( c1.bottom() < c2.bottom() - 2 ) continue; break;
           case 'Q': if( c1.top() < c2.top() + 2 ) continue; break;
-          default : if( c1.bottom() < c2.bottom() + 2 ) continue;
+          default: if( c1.bottom() < c2.bottom() + 2 ) continue;
           }
         c1.only_guess( 'y', 0 );
         }
@@ -538,9 +540,9 @@ void Textline::recognize2( const Charset & charset )
     if( end - begin < 2 ) continue;
     Character & c1 = character( begin );
     if( !c1.guesses() ) continue;
-    int height = c1.height();
-    int code = c1.guess( 0 ).code;
-    if( UCS::isdigit( code ) || code == 'l' || code == 'O' || code == 'o' )
+    const int height = c1.height();
+    const int code1 = c1.guess( 0 ).code;
+    if( UCS::isdigit( code1 ) || code1 == 'l' || code1 == 'O' || code1 == 'o' )
       {
       int digits = 1;
       int i = begin + 1;
@@ -570,7 +572,7 @@ void Textline::recognize2( const Charset & charset )
       }
     }
 
-  // detects Roman numerals 'II', 'III' and 'IIII'
+  // detects Roman numerals 'II', 'III', and 'IIII'
   for( int begin = big_initials(), end = begin; begin < characters(); begin = end + 1 )
     {
     end = find_space_or_hyphen( cpv, begin );
@@ -770,6 +772,48 @@ void Textline::recognize2( const Charset & charset )
       }
     }
 
+  // separate merged 'VV'
+  {
+  int mean_upper_width = 0;
+  for( int i = big_initials(); i < characters(); ++i )
+    {
+    Character & c = character( i );
+    if( !c.guesses() || c.guess( 0 ).code != 'W' || c.width() <= c.height() ||
+        c.blobs() != 1 || c.blob( 0 ).holes() ) continue;
+    if( mean_upper_width == 0 )
+      {
+      int count = 0;
+      for( int j = big_initials(); j < characters(); ++j )
+        {
+        const Character & cj = character( j );
+        if( cj.guesses() && UCS::isupper_normal_width( cj.guess( 0 ).code ) )
+          { mean_upper_width += cj.width(); ++count; }
+        }
+      if( count <= 0 ) break;			// no characters to compare
+      mean_upper_width /= count;
+      }
+    if( c.width() < 2 * mean_upper_width ) continue;
+    const Blob & b = c.blob( 0 );
+    int row = b.bottom();
+    while( row >= b.top() && b.id( row, b.hcenter() ) == 0 ) --row;
+    if( row >= b.vpos( 20 ) ) continue;
+    Rectangle r1( b.left(), b.top(), b.hcenter() - 1, b.bottom() );
+    Rectangle r2( b.hcenter() + 1, b.top(), b.right(), b.bottom() );
+    Blob b1( b, r1 );
+    Blob b2( b, r2 );
+    b1.adjust_height();
+    b2.adjust_height();
+    if( 2 * b1.height() < b.height() || 2 * b2.height() < b.height() ||
+        !Ocrad::similar( b1.height(), b2.height(), 10, 2 ) ) continue;
+    Character c1( new Blob( b1 ) );
+    Character c2( new Blob( b2 ) );
+    c1.only_guess( 'V', 0 );
+    c2.only_guess( 'V', 0 );
+    c = c1;
+    ++i; cpv.insert( cpv.begin() + i, new Character( c2 ) );
+    }
+  }
+
   // join the secuence '', '/', 'o', ' ' into a '%'
   for( int i = big_initials(); i + 2 < characters(); ++i )
     {
