@@ -1,18 +1,18 @@
-/*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003-2019 Antonio Diaz Diaz.
+/* GNU Ocrad - Optical Character Recognition program
+   Copyright (C) 2003-2024 Antonio Diaz Diaz.
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 2 of the License, or
+   (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <algorithm>
@@ -101,7 +101,7 @@ inline void join_blobs( std::vector< Blob * > & blobp_vector,
 
   i = blobp_vector.size();
   while( --i >= 0 && blobp_vector[i] != p2 ) ;
-  if( i < 0 ) Ocrad::internal_error( "join_blobs, lost blob." );
+  if( i < 0 ) throw Ocrad::Internal( "join_blobs: lost blob." );
   blobp_vector.erase( blobp_vector.begin() + i );
 
   p1->add_bitmap( *p2 );
@@ -364,7 +364,7 @@ int analyse_layout( std::vector< Blob * > & blobp_vector,
 void scan_page( const Page_image & page_image, std::vector< Zone > & zone_vector,
                 const int debug_level, const bool layout )
   {
-  const Rectangle & re = page_image;
+  const Rectangle re( page_image.height(), page_image.width() );
   const int zthreshold = page_image.threshold();
   std::vector< Blob * > blobp_vector;
   std::vector< Blob * > old_data( re.width(), (Blob *) 0 );
@@ -432,7 +432,7 @@ void scan_page( const Page_image & page_image, std::vector< Zone > & zone_vector
 
 Textpage::Textpage( const Page_image & page_image, const char * const filename,
                     const Control & control, const bool layout )
-  : Rectangle( page_image ), name( filename )
+  : name( filename )
   {
   const int debug_level = control.debug_level;
   if( debug_level < 0 || debug_level > 100 ) return;
@@ -452,8 +452,8 @@ Textpage::Textpage( const Page_image & page_image, const char * const filename,
   // build a Textblock for every zone with text
   for( unsigned i = 0; i < zone_vector.size(); ++i )
     {
-    Textblock * const tbp = new Textblock( page_image, zone_vector[i].mask,
-                                           zone_vector[i].blobp_vector );
+    Textblock * const tbp = new Textblock( page_image.height(),
+                            zone_vector[i].mask, zone_vector[i].blobp_vector );
     if( tbp->textlines() && debug_level < 90 )
       tbp->recognize( control );
     if( tbp->textlines() ) tbpv.push_back( tbp );
@@ -502,7 +502,7 @@ Textpage::~Textpage()
 const Textblock & Textpage::textblock( const int i ) const
   {
   if( i < 0 || i >= textblocks() )
-    Ocrad::internal_error( "Textpage::textblock, index out of bounds." );
+    throw Ocrad::Internal( "textblock: index out of bounds." );
   return *(tbpv[i]);
   }
 
