@@ -1,18 +1,18 @@
-/*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003-2019 Antonio Diaz Diaz.
+/* GNU Ocrad - Optical Character Recognition program
+   Copyright (C) 2003-2024 Antonio Diaz Diaz.
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 2 of the License, or
+   (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <algorithm>
@@ -27,8 +27,7 @@
 
 namespace {
 
-void error( const char * const msg )
-  { Ocrad::internal_error( msg ); }
+void error( const char * const msg ) { throw Ocrad::Internal( msg ); }
 
 
 int good_reference( const Rectangle & r1, const Rectangle & r2, int & val,
@@ -151,21 +150,21 @@ Vrhomboid::Vrhomboid( const int l, const int lc, const int r, const int rc,
 
 void Vrhomboid::left( const int l )
   {
-  if( l > right_ ) error( "left, bad parameter resizing a Vrhomboid." );
+  if( l > right_ ) error( "left: bad parameter resizing a Vrhomboid." );
   left_ = l;
   }
 
 
 void Vrhomboid::right( const int r )
   {
-  if( r < left_ ) error( "right, bad parameter resizing a Vrhomboid." );
+  if( r < left_ ) error( "right: bad parameter resizing a Vrhomboid." );
   right_ = r;
   }
 
 
 void Vrhomboid::height( const int h )
   {
-  if( h <= 0 ) error( "height, bad parameter resizing a Vrhomboid." );
+  if( h <= 0 ) error( "height: bad parameter resizing a Vrhomboid." );
   height_ = h;
   }
 
@@ -173,7 +172,7 @@ void Vrhomboid::height( const int h )
 void Vrhomboid::extend_left( const int l )
   {
   if( l > right_ )
-    error( "extend_left, bad parameter resizing a Vrhomboid." );
+    error( "extend_left: bad parameter resizing a Vrhomboid." );
   lvcenter_ = vcenter( l ); left_ = l;
   }
 
@@ -181,7 +180,7 @@ void Vrhomboid::extend_left( const int l )
 void Vrhomboid::extend_right( const int r )
   {
   if( r < left_ )
-    error( "extend_right, bad parameter resizing a Vrhomboid." );
+    error( "extend_right: bad parameter resizing a Vrhomboid." );
   rvcenter_ = vcenter( r ); right_ = r;
   }
 
