@@ -1,18 +1,18 @@
-/*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003-2019 Antonio Diaz Diaz.
+/* GNU Ocrad - Optical Character Recognition program
+   Copyright (C) 2003-2024 Antonio Diaz Diaz.
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 2 of the License, or
+   (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <cctype>
@@ -100,39 +100,39 @@ int UCS::compose( const int letter, const int accent )
     case 'A': if( accent == '\'') return CAACUTE;
               if( accent == '`' ) return CAGRAVE;
               if( accent == '^' ) return CACIRCU;
-              if( accent == ':' ) return CADIAER; break;
+              if( accent == ':' ) { return CADIAER; } break;
     case 'E': if( accent == '\'') return CEACUTE;
               if( accent == '`' ) return CEGRAVE;
               if( accent == '^' ) return CECIRCU;
-              if( accent == ':' ) return CEDIAER; break;
+              if( accent == ':' ) { return CEDIAER; } break;
     case 'G': return CGBREVE;
     case '[':
     case 'I': if( accent == '\'') return CIACUTE;
               if( accent == '`' ) return CIGRAVE;
               if( accent == '^' ) return CICIRCU;
-              if( accent == ':' ) return CIDIAER; break;
+              if( accent == ':' ) { return CIDIAER; } break;
     case 'N': if( accent != ':' ) return CNTILDE; break;
     case 'O': if( accent == '\'') return COACUTE;
               if( accent == '`' ) return COGRAVE;
               if( accent == '^' ) return COCIRCU;
-              if( accent == ':' ) return CODIAER; break;
+              if( accent == ':' ) { return CODIAER; } break;
     case 'S': return CSCARON;
     case 'U':
     case 'V': if( accent == '\'') return CUACUTE;
               if( accent == '`' ) return CUGRAVE;
               if( accent == '^' ) return CUCIRCU;
-              if( accent == ':' ) return CUDIAER; break;
+              if( accent == ':' ) { return CUDIAER; } break;
     case 'Y': if( accent == '\'') return CYACUTE;
-              if( accent == ':' ) return CYDIAER; break;
+              if( accent == ':' ) { return CYDIAER; } break;
     case 'Z': return CZCARON;
     case 'a': if( accent == '\'') return SAACUTE;
               if( accent == '`' ) return SAGRAVE;
               if( accent == '^' ) return SACIRCU;
-              if( accent == ':' ) return SADIAER; break;
+              if( accent == ':' ) { return SADIAER; } break;
     case 'e': if( accent == '\'') return SEACUTE;
               if( accent == '`' ) return SEGRAVE;
               if( accent == '^' ) return SECIRCU;
-              if( accent == ':' ) return SEDIAER; break;
+              if( accent == ':' ) { return SEDIAER; } break;
     case '9':
     case 'g': return SGBREVE;
     case '|':
@@ -141,20 +141,20 @@ int UCS::compose( const int letter, const int accent )
     case 'l': if( accent == '\'') return SIACUTE;
               if( accent == '`' ) return SIGRAVE;
               if( accent == '^' ) return SICIRCU;
-              if( accent == ':' ) return SIDIAER; break;
+              if( accent == ':' ) { return SIDIAER; } break;
     case 'n': if( accent != ':' ) return SNTILDE; break;
     case 'o': if( accent == '\'') return SOACUTE;
               if( accent == '`' ) return SOGRAVE;
               if( accent == '^' ) return SOCIRCU;
-              if( accent == ':' ) return SODIAER; break;
+              if( accent == ':' ) { return SODIAER; } break;
     case 's': return SSCARON;
     case 'u':
     case 'v': if( accent == '\'') return SUACUTE;
               if( accent == '`' ) return SUGRAVE;
               if( accent == '^' ) return SUCIRCU;
-              if( accent == ':' ) return SUDIAER; break;
+              if( accent == ':' ) { return SUDIAER; } break;
     case 'y': if( accent == '\'') return SYACUTE;
-              if( accent == ':' ) return SYDIAER; break;
+              if( accent == ':' ) { return SYDIAER; } break;
     case 'z': return SZCARON;
     }
   return 0;
@@ -181,7 +181,7 @@ bool UCS::ishigh( const int code )
     case 'b': case 'd': case 'f': case 'g': case 'h': case 'i': case 'j':
     case 'k': case 'l': case 'p': case 'q': case 't': case 'y': case '|':
       return true;
-    default : return false;
+    default: return false;
     }
   }
 
@@ -203,9 +203,8 @@ bool UCS::islower_ambiguous( const int code )
     case SIGRAVE: case SIACUTE: case SICIRCU: case SIDIAER:
     case SOGRAVE: case SOACUTE: case SOCIRCU: case SOTILDE: case SODIAER:
     case SUGRAVE: case SUACUTE: case SUCIRCU: case SUDIAER:
-    case  SSCEDI: case SSCARON: case SZCARON:
-      return true;
-    default : return false;
+    case  SSCEDI: case SSCARON: case SZCARON: return true;
+    default: return false;
     }
   }
 
@@ -215,10 +214,9 @@ bool UCS::islower_small( const int code )
   if( code >= 128 || !std::islower( code ) ) return false;
   switch( code )
     {
-    case 'a': case 'c': case 'e': case 'm': case 'n': case 'o':
-    case 'r': case 's': case 'u': case 'v': case 'w': case 'x':
-    case 'z': return true;
-    default : return false;
+    case 'a': case 'c': case 'e': case 'm': case 'n': case 'o': case 'r':
+    case 's': case 'u': case 'v': case 'w': case 'x': case 'z': return true;
+    default: return false;
     }
   }
 
@@ -230,7 +228,7 @@ bool UCS::islower_small_ambiguous( const int code )
     {
     case 'c': case 'o': case 's': case 'u': case 'v': case 'w':
     case 'x': case 'z': return true;
-    default : return false;
+    default: return false;
     }
   }
 
@@ -255,7 +253,7 @@ bool UCS::isupper_normal_width( const int code )
   switch( code )
     {
     case 'I': case 'J': case 'L': case 'M': case 'Q': case 'W': return false;
-    default : return true;
+    default: return true;
     }
   }
 
